@@ -284,7 +284,7 @@ function youtubeSearch(query, order) {
     var encodedQuery = encodeURIComponent(query.replace(/\s.\s/gi, " "));
     var safe = Settings.getSetting("safeSearch");
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q=%22"
-                     + encodedQuery + "%22%7C" + encodedQuery.replace(" ", "+") + "&orderby=" + order);
+                     + encodedQuery + "%22%7C" + encodedQuery.replace(/\s/g, "+") + "&orderby=" + order);
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
@@ -292,13 +292,17 @@ function search(query, order) {
     /* Check if xTube is installed and parse the search query */
 
     if (xTubeInstalled) {
+        var youporn = /^yp:/i;
         var youjizz = /^yj:/i;
         var xhamster = /^xh:/i;
-        if (youjizz.test(query)) {
-            youjizzSearch(query.substr(3), order);
+        if (youporn.test(query)) {
+            loadXtubeVideos("youporn", query.slice(3), order);
+        }
+        else if (youjizz.test(query)) {
+            loadXtubeVideos("youjizz", query.slice(3), order);
         }
         else if (xhamster.test(query)) {
-            xhamsterSearch(query.substr(3), order);
+            loadXtubeVideos("xhamster", query.slice(3), order);
         }
         else {
             youtubeSearch(query, order);
