@@ -41,12 +41,12 @@ void Sharing::postToFacebook(const QString &videoId, const QString &title, const
     QByteArray postData;
 
     postData = "access_token=" + facebookToken.toAscii()
-            + "&message=" + message.toAscii().toPercentEncoding()
+            + "&message=" + message.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?")
             + "&link=" + playerUrl
             + "&source=" + embedUrl
             + "&picture=" + thumbUrl
-            + "&name=" + title.toAscii().toPercentEncoding()
-            + "&description=" + description.toAscii().toPercentEncoding()
+            + "&name=" + title.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?")
+            + "&description=" + description.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?")
             + "&attribution=via cuteTube on the Nokia N900";
 
 //    qDebug() << postData;
