@@ -80,10 +80,10 @@ void YouTube::uploadVideo(const QString &filename, const QString &title, const Q
                    "xmlns:media=\"http://search.yahoo.com/mrss/\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
                    "<media:group>\n" \
-                   "<media:title>" + title.toAscii().toPercentEncoding(" ") + "</media:title>\n" \
-                   "<media:description>\n" + description.toAscii().toPercentEncoding(" ") + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
+                   "<media:title>" + title.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</media:title>\n" \
+                   "<media:description>\n" + description.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
                    "<media:category scheme=\"http://gdata.youtube.com/schemas/2007/categories.cat\">\n" + category.toAscii() + "\n</media:category>\n" \
-                   "<media:keywords>" + tags.toAscii().toPercentEncoding(" ") + "</media:keywords>\n" \
+                   "<media:keywords>" + tags.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</media:keywords>\n" \
                    "</media:group>\n" \
                    "</entry>");
 
@@ -175,24 +175,24 @@ void YouTube::uploadFinished() {
 
     if (uploadReply->error()) {
         if (uploadReply->error() == QNetworkReply::OperationCanceledError) {
-            emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "<font>");
+            emit uploadCompleted("<font color='yellow'>" + tr("Upload aborted") + "</font>");
             return;
         }
         else {
             int statusCode = uploadReply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
             if (statusCode == 308) {
                 if (uploadRetries > 0) {
-                    emit uploadCompleted("<font color='yellow'>" + tr("Upload interrupted. Attempting to resume...") + "<font>");
+                    emit uploadCompleted("<font color='yellow'>" + tr("Upload interrupted. Attempting to resume...") + "</font>");
                     QTimer::singleShot(3000, this, SLOT(resumeVideoUpload()));
                 }
                 else {
-                    emit uploadCompleted("<font color='red'>" + tr("Upload failed") + "<font>");
+                    emit uploadCompleted("<font color='red'>" + tr("Upload failed") + "</font>");
                 }
             }
         }
     }
     else {
-        emit uploadCompleted("<font color='green'>" + tr("Upload is completed") + "<font>");
+        emit uploadCompleted("<font color='green'>" + tr("Upload is completed") + "</font>");
     }
 }
 
@@ -213,6 +213,7 @@ void YouTube::postRequest(const QUrl &url, const QByteArray &xml) {
 void YouTube::postFinished() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
+        emit alert(tr("Error - YouTube server unreachable"));
         return;
     }
 
@@ -285,8 +286,8 @@ void YouTube::createNewPlaylist(const QString &title, const QString &description
     QByteArray xml("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" \
                    "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
-                   "<title>" + title.toAscii().toPercentEncoding(" ") + "</title>\n" \
-                   "<summary>" + description.toAscii().toPercentEncoding(" ") + "</summary>\n" \
+                   "<title>" + title.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</title>\n" \
+                   "<summary>" + description.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</summary>\n" \
                    "</entry>");
     if (isPrivate) {
         int index = xml.lastIndexOf("<");
@@ -338,7 +339,7 @@ void YouTube::addComment(const QString &videoId, const QString &comment) {
     QByteArray xml("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" \
                    "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
-                   "<content>" + comment.toAscii().toPercentEncoding(" ") + "</content>\n" \
+                   "<content>" + comment.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</content>\n" \
                    "</entry>");
     postRequest(url, xml);
     connect(this, SIGNAL(postSuccessful()), this, SIGNAL(commentAdded()));
@@ -352,7 +353,7 @@ void YouTube::replyToComment(const QString &videoId, const QString &commentId, c
                    "<link rel=\"http://gdata.youtube.com/schemas/2007#in-reply-to\"\n" \
                    "type=\"application/atom+xml\"\n" \
                    "href=\"http://gdata.youtube.com/feeds/api/videos/" + videoId.toAscii() + "/comments/" + commentId.toAscii() + "\"/>\n" \
-                   "<content>" + comment.toAscii().toPercentEncoding(" ") + "</content>\n" \
+                   "<content>" + comment.toAscii().toPercentEncoding(" \n\t#[]{}=+$&*()<>@|',/!\":;?") + "</content>\n" \
                    "</entry>");
     postRequest(url, xml);
 }
